pygeodesy.errors

Package pygeodesy :: Module errors |
[frames] | no frames]

# Module errors

Errors, exceptions, exception formatting and exception chaining.

Error, exception classes and functions to format PyGeodesy errors, including the setting of exception chaining for Python 3.9+.

By default, exception chaining is turned off. To enable exception chaining, use command line option `python -X dev` OR set env variable `PYTHONDEVMODE=1` or to any non-empty string OR set env variable `PYGEODESY_EXCEPTION_CHAINING=std` or to any non-empty string.

Version: 26.02.12

Classes
| AuxError Error raised for a rhumb.aux_, `Aux`, `AuxDLat` or `AuxLat` issue.
| ClipError Clip box or clip region issue.
| CrossError Error raised for zero or near-zero vectorial cross products, occurring for coincident or colinear points, lines or bearings.
| GeodesicError Error raised for convergence or other issues in geodesicx, geodesicw, geodsolve or karney.
| IntersectionError Error raised for line or circle intersection issues.
| LenError Error raised for mis-matching `len` values.
| LimitError Error raised for lat- or longitudinal values or deltas exceeding the given `limit` in functions equirectangular, equirectangular4, `nearestOn*` and `simplify*` or methods with `limit` or `options` keyword arguments.
| MGRSError Military Grid Reference System (MGRS) parse or other Mgrs issue.
| NumPyError Error raised for `NumPy` issues.
| ParseError Error parsing degrees, radians or several other formats.
| PointsError Error for an insufficient number of points.
| RangeError Error raised for lat- or longitude values outside the `clip`, `clipLat`, `clipLon` in functions parse3llh, parseDMS, parseDMS2 and parseRad or the `limit` set with functions clipDegrees and clipRadians.
| RhumbError Error raised for a rhumb aux_, ekx or solve issue.
| TriangleError Error raised for triangle, intersection or resection issues.
| SciPyError Error raised for `SciPy` issues.
| SciPyWarning Error thrown for `SciPy` warnings.
| TRFError Terrestrial Reference Frame (TRF), Epoch, RefFrame or RefFrame conversion issue.
| UnitError Default exception for units issues for a value exceeding the `low` or `high` limit.
| VectorError Vector3d, `Cartesian*` or `*Nvector` issues.

Functions
crosserrors(raiser=None) Report or ignore vectorial cross product errors. |
exception_chaining(exc=None) Get an error's cause or the exception chaining setting. |
isError(exc) Check a (caught) exception. |
limiterrors(raiser=None) Get/set the throwing of LimitErrors. |
rangerrors(raiser=None) Get/set the throwing of RangeErrors. |

Variables
| __all__ = `_ALL_LAZY.errors`

Function Details

### crosserrors (raiser=None) |
Report or ignore vectorial cross product errors. Arguments: `raiser` - Use `True` to throw, `False` to ignore CrossError exceptions or `None` to leave the setting unchanged. Returns: Previous setting (`bool`). See Also: Property `Vector3d[Base].crosserrors`.

### exception_chaining (exc=None) |
Get an error's cause or the exception chaining setting. Arguments: `exc` - An error instance (`Exception`) or `None`. Returns: If `exc is None`, return `True` if exception chaining is enabled for PyGeodesy errors, `False` if turned off and `None` if not available. If `exc is not None`, return it's error cause or `None` if there is none. Note: To enable exception chaining for `pygeodesy` errors, set env var `PYGEODESY_EXCEPTION_CHAINING` to any non-empty value prior to `import pygeodesy`.

### isError (exc) |
Check a (caught) exception. Arguments: `exc` - The exception C({Exception}). Returns: `True` if `exc` is a `pygeodesy` error, `False` if `exc` is a standard Python error of `None` if neither.

### limiterrors (raiser=None) |
Get/set the throwing of LimitErrors. Arguments: `raiser` - Use `True` to raise, `False` to ignore LimitError exceptions or `None` to leave the setting unchanged. Returns: Previous setting (`bool`).

### rangerrors (raiser=None) |
Get/set the throwing of RangeErrors. Arguments: `raiser` - Use `True` to raise or `False` to ignore RangeError exceptions or `None` to leave the setting unchanged. Returns: Previous setting (`bool`).